@@ -255,7 +255,7 @@ int main(int argc, char** argv)
 
 	// decode parameters
 	int c = 0;     
-	while ((c = getopt (argc, argv, "v::Q:O:b:" "I:P:p:m:u:M:ct:S::" "R:U:" "rwBsf::F:W:H:G:" "A:C:a:" "Vh")) != -1)
+	while ((c = getopt (argc, argv, "v::Q:O:b:" "I:P:p:m::u:M:ct:S::" "R:U:" "rwBsf::F:W:H:G:" "A:C:a:" "Vh")) != -1)
 	{
 		switch (c)
 		{
@@ -269,7 +269,7 @@ int main(int argc, char** argv)
 			case 'P':	rtspPort                = atoi(optarg); break;
 			case 'p':	rtspOverHTTPPort        = atoi(optarg); break;
 			case 'u':	url                     = optarg; break;
-			case 'm':	multicast = true; murl  = optarg; break;
+			case 'm':	multicast = true; murl  = optarg ? optarg : murl; break;
 			case 'M':	multicast = true; maddr = optarg; break;
 			case 'c':	repeatConfig            = false; break;
 			case 't':	timeout                 = atoi(optarg); break;
@@ -523,7 +523,11 @@ int main(int argc, char** argv)
 				nbSource += rtspServer.addSession(baseUrl+tsurl, subSession);
 				
 				struct in_addr ip;
+#if LIVEMEDIA_LIBRARY_VERSION_INT	<	1611878400				
 				ip.s_addr = ourIPAddress(*rtspServer.env());
+#else
+				ip.s_addr = ourIPv4Address(*rtspServer.env());
+#endif
 				LOG(NOTICE) << "HLS       http://" << inet_ntoa(ip) << ":" << rtspPort << "/" << baseUrl+tsurl << ".m3u8";
 				LOG(NOTICE) << "MPEG-DASH http://" << inet_ntoa(ip) << ":" << rtspPort << "/" << baseUrl+tsurl << ".mpd";
 			}
